use std::collections::HashMap;
use std::sync::Mutex;
use chrono::{DateTime, Utc};

pub type State = Mutex<HashMap<String, Mailbox>>;

pub fn fresh_state() -> State {
    Mutex::new(HashMap::new())
}

pub struct Message {
    pub from: String,
    pub received: DateTime<Utc>,
    pub subject: String,
    pub body: String
}

pub struct Mailbox {
    pub email: String,
    pub messages: Vec<Message>,
    pub created_at: DateTime<Utc>
}

impl Mailbox {
    pub fn new(email: String) -> Self {
       Self {
           email,
           messages: Vec::new(),
           created_at: Utc::now()
       }
    }
}